dot-CheckRooted: Check that trees are rooted

.CheckRootedR Documentation

Check that trees are rooted

Description

Check that trees are rooted

Usage

.CheckRooted(trees)

Arguments

trees

A phylo object or a list of phylo objects.

Value

Called for its side-effect (stops with an error if any tree is unrooted).


TBRDist documentation built on Sept. 2, 2026, 5:09 p.m.